==> huaweicloudsdkgaussdb-3.1.100-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/show_intelligent_diagnosis_instance_infos_per_metric_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowIntelligentDiagnosisInstanceInfosPerMetricResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_count': 'int',
        'instance_infos': 'list[InstanceInfoForDiagnosis]'
    }

    attribute_map = {
        'total_count': 'total_count',
        'instance_infos': 'instance_infos'
    }

    def __init__(self, total_count=None, instance_infos=None):
        """ShowIntelligentDiagnosisInstanceInfosPerMetricResponse

        The model defined in huaweicloud sdk

        :param total_count: 当前指标的异常实例总数。
        :type total_count: int
        :param instance_infos: 异常实例信息。
        :type instance_infos: list[:class:`huaweicloudsdkgaussdb.v3.InstanceInfoForDiagnosis`]
        """
        
        super(ShowIntelligentDiagnosisInstanceInfosPerMetricResponse, self).__init__()

        self._total_count = None
        self._instance_infos = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if instance_infos is not None:
            self.instance_infos = instance_infos

    @property
    def total_count(self):
        """Gets the total_count of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.

        当前指标的异常实例总数。

        :return: The total_count of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.

        当前指标的异常实例总数。

        :param total_count: The total_count of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def instance_infos(self):
        """Gets the instance_infos of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.

        异常实例信息。

        :return: The instance_infos of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdb.v3.InstanceInfoForDiagnosis`]
        """
        return self._instance_infos

    @instance_infos.setter
    def instance_infos(self, instance_infos):
        """Sets the instance_infos of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.

        异常实例信息。

        :param instance_infos: The instance_infos of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.
        :type instance_infos: list[:class:`huaweicloudsdkgaussdb.v3.InstanceInfoForDiagnosis`]
        """
        self._instance_infos = instance_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowIntelligentDiagnosisInstanceInfosPerMetricResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/show_intelligent_diagnosis_instance_infos_per_metric_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowIntelligentDiagnosisInstanceInfosPerMetricResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_count': 'int',
        'instance_infos': 'list[InstanceInfoForDiagnosis]'
    }

    attribute_map = {
        'total_count': 'total_count',
        'instance_infos': 'instance_infos'
    }

    def __init__(self, total_count=None, instance_infos=None):
        r"""ShowIntelligentDiagnosisInstanceInfosPerMetricResponse

        The model defined in huaweicloud sdk

        :param total_count: 当前指标的异常实例总数。
        :type total_count: int
        :param instance_infos: 异常实例信息。
        :type instance_infos: list[:class:`huaweicloudsdkgaussdb.v3.InstanceInfoForDiagnosis`]
        """
        
        super(ShowIntelligentDiagnosisInstanceInfosPerMetricResponse, self).__init__()

        self._total_count = None
        self._instance_infos = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if instance_infos is not None:
            self.instance_infos = instance_infos

    @property
    def total_count(self):
        r"""Gets the total_count of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.

        当前指标的异常实例总数。

        :return: The total_count of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.

        当前指标的异常实例总数。

        :param total_count: The total_count of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def instance_infos(self):
        r"""Gets the instance_infos of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.

        异常实例信息。

        :return: The instance_infos of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdb.v3.InstanceInfoForDiagnosis`]
        """
        return self._instance_infos

    @instance_infos.setter
    def instance_infos(self, instance_infos):
        r"""Sets the instance_infos of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.

        异常实例信息。

        :param instance_infos: The instance_infos of this ShowIntelligentDiagnosisInstanceInfosPerMetricResponse.
        :type instance_infos: list[:class:`huaweicloudsdkgaussdb.v3.InstanceInfoForDiagnosis`]
        """
        self._instance_infos = instance_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowIntelligentDiagnosisInstanceInfosPerMetricResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
